<?php

function resizeImage($srcImage, $targetWidth, $targetHeight) {
	
	$srcWidth = imagesx($srcImage);
	$srcHeight = imagesy($srcImage);
	
	$srcRatio = $srcWidth/$srcHeight;
	$targetRatio = $targetWidth/$targetHeight;
	
	$tmpWidth = 0;
	$tmpHeight = 0;
	$tmpImage = null;
	
	if($srcRatio > $targetRatio) {
		$tmpHeight = $srcHeight;
		$tmpWidth = ($tmpHeight*$targetWidth)/$targetHeight;
		$startXPos = ($srcWidth-$tmpWidth)/2;
		$tmpImage = imagecreatetruecolor($tmpWidth, $tmpHeight);
		imagecopy($tmpImage, $srcImage, 0, 0, $startXPos, 0, $tmpWidth, $tmpHeight);
	} else {
		$tmpWidth = $srcWidth;
		$tmpHeight = ($tmpWidth*$targetHeight)/$targetWidth;
		$startYPos = ($srcHeight-$tmpHeight)/2;
		$tmpImage = imagecreatetruecolor($tmpWidth, $tmpHeight);
		imagecopy($tmpImage, $srcImage, 0, 0, 0, $startYPos, $tmpWidth, $tmpHeight);
	}
	
	$destImage = imagecreatetruecolor($targetWidth, $targetHeight);
	imagecopyresampled($destImage, $tmpImage, 0, 0, 0, 0, $targetWidth, $targetHeight, $tmpWidth, $tmpHeight);
	
	imagedestroy($tmpImage);
	
	return $destImage;
	
}

function resizeImageFromFileToFile($srcImageName, $targetImageName, $targetWidth, $targetHeight) {
	
	if(!isImageFile($srcImageName) || !getimagesize($srcImageName)) {
		throw new Exception('[imagesUtil][resizeImageFromFileToFile]: error while reading image info: '.$srcImageName);
	}
	
	$srcImage = null;
	
	if(preg_match(JPG_IMAGE_FILES_REGEXP, $srcImageName)) {
		$srcImage = imagecreatefromjpeg($srcImageName);
	} elseif(preg_match(PNG_IMAGE_FILES_REGEXP, $srcImageName)) {
		$srcImage = imagecreatefrompng($srcImageName);
	} else {
		throw new Exception('[imagesUtil][resizeImageFromFileToFile]: unknown image format: '.$srcImageName);
	}
	
	$resizedImage = resizeImage($srcImage, $targetWidth, $targetHeight);
	
	if(preg_match(JPG_IMAGE_FILES_REGEXP, $targetImageName)) {
		if(!imagejpeg($resizedImage, $targetImageName)) {
			throw new Exception('[imagesUtil][resizeImageFromFileToFile]: error while writing image: '.$targetImageName);
		}
	} elseif(preg_match(PNG_IMAGE_FILES_REGEXP, $targetImageName)) {
		if(!imagepng($resizedImage, $targetImageName)) {
			throw new Exception('[imagesUtil][resizeImageFromFileToFile]: error while writing image: '.$targetImageName);
		}
	} else {
		throw new Exception('[imagesUtil][resizeImageFromFileToFile]: unknown image format: '.$targetImageName);
	}
	
	imagedestroy($resizedImage);
	imagedestroy($srcImage);
	
}

function resizeImagesFromDirToDir($srcPath, $targetPath, $targetWidth, $targetHeight) {
	$fileArray = getFilesList($srcPath, IMAGE_FILES_REGEXP, SCANDIR_SORT_ASCENDING);
	
	if(!empty($fileArray)) {
		if(!file_exists($targetPath)) {
			mkdir($targetPath);
		}
		
		foreach($fileArray as $file) {
			resizeImageFromFileToFile($srcPath.'/'.$file, $targetPath.'/'.$file, $targetWidth, $targetHeight);
		}
	}
}

?>